/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2007. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *******************************************************************************/
package com.example.hellojazz.client.tests;

import junit.framework.TestCase;

import com.example.hellojazz.client.IHelloJazzClientLibrary;
import com.ibm.team.repository.client.ITeamRepository;
import com.ibm.team.repository.client.TeamPlatform;
import com.ibm.team.repository.common.TeamRepositoryException;

public class TestHelloJazz extends TestCase {

	private ITeamRepository repo;

	protected void setUp() throws Exception {
		super.setUp();

		if (!TeamPlatform.isStarted())
			TeamPlatform.startup();

		repo = login();
	}

	protected void tearDown() throws Exception {
		repo.logout();
		assertFalse(repo.loggedIn());
		repo = null;
		
		super.tearDown();
	}

	public void testSayHello() throws TeamRepositoryException {
		IHelloJazzClientLibrary library = (IHelloJazzClientLibrary) repo
				.getClientLibrary(IHelloJazzClientLibrary.class);
		assertNotNull(library);
		String result = library.sayHello();
		assertNotNull(result);
		return;
	}

	/**
	 * The URI scheme <code>"local:"</code> creates a Jazz server on the same
	 * thread as the client.
	 */
	private static final String REPOSITORY_URI = "local:";

	private ITeamRepository login() throws TeamRepositoryException {
		ITeamRepository repository = TeamPlatform.getTeamRepositoryService()
				.getUnmanagedRepository(REPOSITORY_URI);
		assertFalse(repository.loggedIn());
		repository.registerLoginHandler(new ITeamRepository.ILoginHandler() {
			public ILoginInfo challenge(ITeamRepository repo) {
				return new ILoginInfo() {
					public String getUserId() {
						return "ADMIN";
					}

					public String getPassword() {
						return "ADMIN";
					}
				};
			}
		});
		repository.login(null);
		assertTrue(repository.loggedIn());
		return repository;
	}
}
