/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2007. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *******************************************************************************/
package com.example.hellojazz.client.internal;

import com.example.hellojazz.client.IHelloJazzClientLibrary;
import com.example.hellojazz.common.service.IHelloJazzService;
import com.ibm.team.repository.client.util.IClientLibraryContext;
import com.ibm.team.repository.common.TeamRepositoryException;

public class HelloJazzClientLibrary implements IHelloJazzClientLibrary {
    /**
     * The client library context, which identifies the repository,
     * and provides access to services.
     */
    private final IClientLibraryContext context;

    /**
     * Creates the {@link IHelloJazzClientLibrary} implementation.
     * 
     * @param context
     *            The client library context. Must not be null.
     */
    HelloJazzClientLibrary(IClientLibraryContext context) {
        if (context == null) {
            throw new IllegalArgumentException(
                    "context must not be null");
        }
        this.context = context;
    }

    /**
     * Returns the {@link IHelloJazzService} implementation.
     * @return Returns an {@link IHelloJazzService} implementation.
     *         Never null.
     * @exception TeamRepositoryException
     *         Thrown if the {@link IHelloJazzService} cannot be
     *         retrieved.
     */
    private IHelloJazzService getService()
    throws TeamRepositoryException {
        IHelloJazzService service = (IHelloJazzService)
            context.getServiceInterface(IHelloJazzService.class);
        if (service == null) {
            throw new TeamRepositoryException(
                    "Unable to get IHelloJazzService");
        }
        return service;
    }    

    /**
     * Calls the IHelloJazzService.sayHello method on the server, and
     * returns its result.
     * 
     * @return The string returned from the server.
     * @exception TeamRepositoryException
     *         Thrown if something goes wrong.
     */
    public String sayHello() throws TeamRepositoryException {
        String result = getService().sayHello();
        return result;
    }
}
