/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2007. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *******************************************************************************/
package com.example.hellojazz.rcp.ui.actions;

import java.lang.reflect.InvocationTargetException;

import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.jface.dialogs.ProgressMonitorDialog;
import org.eclipse.jface.operation.IRunnableWithProgress;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.ui.IObjectActionDelegate;
import org.eclipse.ui.IWorkbenchPart;

import com.example.hellojazz.client.IHelloJazzClientLibrary;
import com.ibm.team.repository.client.ITeamRepository;
import com.ibm.team.repository.common.TeamRepositoryException;

public class HelloJazzAction implements IObjectActionDelegate {

	private Shell _shell;
	private ITeamRepository _selectedRepository;

	public void setActivePart(IAction action, IWorkbenchPart targetPart) {
		_shell = targetPart.getSite().getShell();
	}

	public void run(IAction action) {

		ITeamRepository repository = _selectedRepository;
		if (repository == null) {
			MessageDialog.openError(_shell, null, "No selected Repository!");
			return;
		}

		IHelloJazzClientLibrary library = (IHelloJazzClientLibrary) repository
				.getClientLibrary(IHelloJazzClientLibrary.class);
		if (library == null) {
			MessageDialog.openError(_shell, null,
					"Failed to get IHelloJazzClientLibrary!");
			return;
		}

		HelloJazzRunnable runnable = new HelloJazzRunnable(library);
		ProgressMonitorDialog dialog = new ProgressMonitorDialog(_shell);

		try {
			dialog.run(true, false, runnable);
		} catch (Exception e) {
			MessageDialog.openError(_shell, null, e.getMessage());
		}

		String title = runnable.getHelloMessage();
		String body = "repository name: " + repository.getName() + "\n"
				+ "repository URI: " + repository.getRepositoryURI() + "\n"
				+ "message: " + runnable.getHelloMessage();

		MessageDialog.openInformation(_shell, title, body);
	}

	static class HelloJazzRunnable implements IRunnableWithProgress {
		private final IHelloJazzClientLibrary _library;
		private String _message;

		HelloJazzRunnable(IHelloJazzClientLibrary library) {
			_library = library;
		}

		String getHelloMessage() {
			return _message;
		}

		public void run(IProgressMonitor monitor)
				throws InvocationTargetException, InterruptedException {

			monitor.beginTask("Contacting Jazz Repository...", 2);
			monitor.worked(1);

			try {
				_message = _library.sayHello();
			} catch (TeamRepositoryException e) {
				_message = e.getMessage();
			} finally {
				monitor.done();
			}
		}
	}

	public void selectionChanged(IAction action, ISelection selection) {
		_selectedRepository = null;

		if (selection instanceof IStructuredSelection) {
			Object first = ((IStructuredSelection) selection).getFirstElement();
			if (first instanceof ITeamRepository) {
				_selectedRepository = (ITeamRepository) first;
			}
		}
	}
}